@@ -7,9 +7,9 @@
  * Needs Javascript
  * @copyright (c) 2002 Kelvin Ho
  * @copyright (c) 2002-2004 Jon Nelson <quincy at linuxnotes.net>
- * @copyright (c) 2004-2007 The SquirrelMail Project Team
+ * @copyright (c) 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: abook_group_interface.php,v 1.12 2007/01/28 10:54:47 tokul Exp $
+ * @version $Id: abook_group_interface.php,v 1.10 2006/09/13 16:36:42 tokul Exp $
  * @package sm-plugins
  * @subpackage abook_group
  */
@@ -80,11 +80,11 @@ function addr_display_result($res, $includesource = true) {
         if ($line % 2) { echo ' bgcolor="' . $color[0] . '"'; }
         echo ' nowrap><td nowrap align=center width="5%">' .
             '<input type=checkbox name="send_to_search[T' . $line . ']" value = "' .
-            htmlspecialchars($row['email']) . '">&nbsp;' . _("To") . '&nbsp;' .
+            htmlspecialchars($row['email']) . '">&nbsp;To&nbsp;' .
             '<input type=checkbox name="send_to_search[C' . $line . ']" value = "' .
-            htmlspecialchars($row['email']) . '">&nbsp;' . _("Cc") . '&nbsp;' .
+            htmlspecialchars($row['email']) . '">&nbsp;Cc&nbsp;' .
             '<input type=checkbox name="send_to_search[B' . $line . ']" value = "' .
-            htmlspecialchars($row['email']) . '">&nbsp;' . _("Bcc") . '&nbsp;' . 
+            htmlspecialchars($row['email']) . '">&nbsp;Bcc&nbsp;' . 
             '</td><td nowrap>&nbsp;' . $row['name'] . '&nbsp;</td>' .
             '<td nowrap>&nbsp;' . $row['email'] . '&nbsp;</td>' .
             '<td nowrap>&nbsp;' . $row['label'] . '&nbsp;</td>';
@@ -112,9 +112,6 @@ displayHtmlHeader();
 // FIXME: check if $color is not empty
 echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\">\n\n";
 
-bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
-textdomain('abook_group');
-
 /* Initialize addressbook */
 
 $myparams = array();
@@ -134,7 +131,13 @@ insert_javascript();
 ?>
 <table width="98%" align="center" cellpadding="2" cellspacing="2" border="0">
 <tr><td bgcolor="<?php echo $color[0] ?>">
-   <center><b><?php echo _("Groups"); ?></b></center>
+   <center><b><?php 
+    bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+    textdomain('abook_group');
+    echo _("Groups");
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
+?></b></center>
 </td></tr></table>
 <?php 
 if (count($myGroups)>0) { 
@@ -146,18 +149,15 @@ if (count($myGroups)>0) {
         $cc_address = "";
         $bcc_address = "";
         for ($j=0;$j<count($myGroupMembers);$j++){
-            // single quotes and slashes are escaped with \, 
-            // then string is sanitized with htmlspecialchars (catches double quotes and amp)
-            $address = htmlspecialchars(addcslashes($myGroupMembers[$j]['email'],"'\\"));
-            $to_address .= "to_address('" . $address . "');";
-            $cc_address .= "cc_address('" . $address . "');";
-            $bcc_address .= "bcc_address('" . $address . "');";
+            $to_address .= "to_address('{$myGroupMembers[$j]['email']}');";
+            $cc_address .= "cc_address('{$myGroupMembers[$j]['email']}');";
+            $bcc_address .= "bcc_address('{$myGroupMembers[$j]['email']}');";
         }
 ?>
 <table><tr>
-   <td><a href="javascript:void(0)" onclick="<?php echo $to_address ?>"><?php echo _("To"); ?></a> 
-       <a href="javascript:void(0)" onclick="<?php echo $cc_address ?>"><?php echo _("Cc"); ?></a> 
-       <a href="javascript:void(0)" onclick="<?php echo $bcc_address ?>"><?php echo _("Bcc"); ?></a>
+   <td><a href="javascript:void(0)" onclick="<?php echo $to_address ?>">To</a> 
+       <a href="javascript:void(0)" onclick="<?php echo $cc_address ?>">Cc</a> 
+       <a href="javascript:void(0)" onclick="<?php echo $bcc_address ?>">Bcc</a>
    </td>
    <td><?php echo $groupName ?>
    </td>
@@ -168,7 +168,11 @@ if (count($myGroups)>0) {
 </table>
 <?php
 } else{
+    bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+    textdomain('abook_group');
     echo  _("There are no groups available for selection");
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
 }
 echo '<table align="center" bgcolor="'.$color[0].'" width="98%" border="0">'."\n" 
     .'<tr><td>&nbsp;</td>'
