@@ -7,7 +7,7 @@
  * @copyright (c) 2002-2004 Jon Nelson <quincy at linuxnotes.net>
  * @copyright (c) 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: listMembers.php,v 1.12 2007/01/20 08:27:48 tokul Exp $
+ * @version $Id: listMembers.php,v 1.11 2006/09/13 16:36:42 tokul Exp $
  * @package sm-plugins
  * @subpackage abook_group
  */
@@ -125,7 +125,7 @@ if(is_array($myGroupMembers) && count($myGroupMembers)>0) {
 </table>
 <?php
 //end count > 0
-} elseif (! empty($abookGroups->error)) {
+} elseif (! $myGroupMembers) {
      error_box($abookGroups->error,$color);
 } else{
     bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
