@@ -1,12 +1,18 @@
 <?php
-
 /**
  * list_abook_group.php
  *
- * 2002 @ Kelvin Ho. abook_group_plugin v0.1
- *
  * List abook groups for modify, delete or to list group members.
+ * @copyright (c) 2002 Kelvin Ho
+ * @copyright (c) 2002-2004 Jon Nelson <quincy at linuxnotes.net>
+ * @copyright (c) 2004-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: list_abook_group.php,v 1.8 2006/09/13 16:36:42 tokul Exp $
+ * @package sm-plugins
+ * @subpackage abook_group
  */
+
+/** @ignore */
 if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
@@ -14,12 +20,13 @@ include_once(SM_PATH . 'functions/addressbook.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_database.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
-global $mailbox, $username;
+global $username;
 
 /*  Start globals  */
 
-sqgetGlobalVar('username', $username, SQ_POST);
-sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+//sqgetGlobalVar('username', $username, SQ_POST);
+// we are not in mailbox
+// sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
 sqgetGlobalVar('myparams', $myparams, SQ_POST);
 sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
 sqgetGlobalVar('myGroups', $myGroups, SQ_POST);
@@ -28,7 +35,7 @@ sqgetGlobalVar('groupNameURL', $groupNameURL, SQ_POST);
 
 /*  End globals  */
 
-displayPageHeader($color, $mailbox);
+displayPageHeader($color, 'None');
 
 /* Initialize addressbook */
 
@@ -42,7 +49,7 @@ $myGroups = $abookGroups->list_group();
 
 ?>
 
-<table width="95%" align=center cellpadding=2 cellspacing=2 border=0>
+<table width="95%" align="center" cellpadding="2" cellspacing="2" border="0">
 <tr><td bgcolor="<?php echo $color[0] ?>">
    <center><b>
 <?php 
@@ -80,8 +87,7 @@ for ($i=0;$i<count($myGroups);$i++){
   <?php } ?>
 </table>
 <?php
-}
-else{
+} else {
 ?>
 <p><center>
 <?php 
@@ -94,7 +100,6 @@ textdomain('squirrelmail');
 </center></p>
 <?php
 }
-
 display_abook_group_footer();
 ?>
 </body></html>
